# Fyodorov Utils

<p>
<img alt="GitHub Contributors" src="https://img.shields.io/github/contributors/fyodorovai/fyodorov-utils" />
<img alt="GitHub Last Commit" src="https://img.shields.io/github/last-commit/fyodorovai/fyodorov-utils" />
<img alt="" src="https://img.shields.io/github/repo-size/fyodorovai/fyodorov-utils" />
<img alt="GitHub Issues" src="https://img.shields.io/github/issues/fyodorovai/fyodorov-utils" />
<img alt="GitHub Pull Requests" src="https://img.shields.io/github/issues-pr/fyodorovai/fyodorov-utils" />
</p>

`fyodorov-utils` is a Python library that provides a collection of utility functions and classes used across multiple services within the Fyodorov project. The Fyodorov project is a suite of complementary services for working with LLM-based agents.

## Installation

You can install `fyodorov-utils` using pip: 
```shell
pip install fyodorov-utils==0.0.1
```
